@@ -402,7 +402,7 @@ public class FileItemDatabase implements ChangeExecListener {
 
             queryStmt.setString(1, subGroupId);
 
-            return implExecuteQuery(groupId, queryStmt);
+            return implExecuteQuery(con, groupId, queryStmt);
         } catch (Exception e) {
             throw new FileItemException(e);
         }
@@ -433,8 +433,8 @@ public class FileItemDatabase implements ChangeExecListener {
 
             FileItemUtils.setStatementValues(queryStmt, customProperties.values().toArray(), 1);
 
-            return implExecuteQuery(groupId, queryStmt);
-        } catch (SQLException e) {
+            return implExecuteQuery(con, groupId, queryStmt);
+        } catch (Exception e) {
             throw new FileItemException(e);
         }
     }
@@ -448,8 +448,8 @@ public class FileItemDatabase implements ChangeExecListener {
         try (final Connection con = getReadConnection();
              final PreparedStatement customQueryStmt = con.prepareStatement(customQuerySQL)) {
 
-            return implExecuteQuery(groupId, customQueryStmt, returnValues);
-        } catch (SQLException e) {
+            return implExecuteQuery(con, groupId, customQueryStmt, returnValues);
+        } catch (Exception e) {
             throw new FileItemException(e);
         }
     }
@@ -573,46 +573,50 @@ public class FileItemDatabase implements ChangeExecListener {
         }
 
         try (final Connection con = getReadConnection();
-            final PreparedStatement stmt = con.prepareStatement(querySql.toString());
-            final ResultSet resultSet = stmt.executeQuery()) {
+            final PreparedStatement stmt = con.prepareStatement(querySql.toString())) {
 
             long ret = 0;
 
-            if (null != resultSet) {
-               while (resultSet.next()) {
-                   final String subGroupId = resultSet.getString(1);
-                   final long subGroupLength = resultSet.getLong(2);
-                   final long subGroupCreateDateMillis = resultSet.getLong(3);
-                   final long subGroupModificationDateMillis = resultSet.getLong(4);
+            try (final ResultSet resultSet = stmt.executeQuery()) {
+                if (null != resultSet) {
+                    while (resultSet.next()) {
+                        final String subGroupId = resultSet.getString(1);
+                        final long subGroupLength = resultSet.getLong(2);
+                        final long subGroupCreateDateMillis = resultSet.getLong(3);
+                        final long subGroupModificationDateMillis = resultSet.getLong(4);
 
-                   ++ret;
+                        ++ret;
 
-                   if (null != subGroupConsumer) {
-                       subGroupConsumer.accept(new ISubGroup() {
+                        if (null != subGroupConsumer) {
+                            subGroupConsumer.accept(new ISubGroup() {
 
-                            @Override
-                            public String getSubGroupId() {
-                                return subGroupId;
-                            }
+                                @Override
+                                public String getSubGroupId() {
+                                    return subGroupId;
+                                }
 
-                            @Override
-                            public long getLength() {
-                                return subGroupLength;
-                            }
+                                @Override
+                                public long getLength() {
+                                    return subGroupLength;
+                                }
 
-                            @Override
-                            public Date getCreateDate() {
-                                return new Date(subGroupCreateDateMillis);
-                            }
+                                @Override
+                                public Date getCreateDate() {
+                                    return new Date(subGroupCreateDateMillis);
+                                }
 
-                            @Override
-                            public Date getModificationDate() {
-                                return new Date(subGroupModificationDateMillis);
-                            }
-                       });
-                   }
-               }
-           }
+                                @Override
+                                public Date getModificationDate() {
+                                    return new Date(subGroupModificationDateMillis);
+                                }
+                            });
+                        }
+                    }
+                }
+            } finally {
+                // commit even pure query statements, since they could produce transactions (e.g. for AWS RDB)
+                con.commit();
+            }
 
             return ret;
         } catch (SQLException e) {
@@ -689,6 +693,9 @@ public class FileItemDatabase implements ChangeExecListener {
                 if ((null != resultSet) && resultSet.first()) {
                     return new FileStoreData(resultSet.getInt(1), resultSet.getString(2));
                 }
+            } finally {
+                // commit even pure query statements, since they could produce transactions (e.g. for AWS RDB)
+                con.commit();
             }
         } catch (SQLException e) {
             throw new FileItemException(e);
@@ -747,6 +754,9 @@ public class FileItemDatabase implements ChangeExecListener {
 
                     return ret;
                 }
+            } finally {
+                // commit even pure query statements, since they could produce transactions (e.g. for AWS RDB)
+                con.commit();
             }
         } catch(SQLException e) {
            throw new FileItemException(e);
@@ -927,6 +937,9 @@ public class FileItemDatabase implements ChangeExecListener {
                 }
 
                 return idList.toArray(new String[idList.size()]);
+            } finally {
+                // commit even pure query statements, since they could produce transactions (e.g. for AWS RDB)
+                con.commit();
             }
         }
     }
@@ -948,6 +961,9 @@ public class FileItemDatabase implements ChangeExecListener {
                 if ((null != resultSet) && resultSet.first()) {
                     return resultSet.getLong(1);
                 }
+            } finally {
+                // commit even pure query statements, since they could produce transactions (e.g. for AWS RDB)
+                con.commit();
             }
         }
 
@@ -980,6 +996,9 @@ public class FileItemDatabase implements ChangeExecListener {
                     return ((null != resultSet) && resultSet.first()) ?
                         resultSet.getBoolean(1) :
                             false;
+                } finally {
+                    // commit even pure query statements, since they could produce transactions (e.g. for AWS RDB)
+                    con.commit();
                 }
             } catch (SQLException e) {
                 throw new FileItemException("Error while deleting entry(ies))", e);
@@ -1089,8 +1108,6 @@ public class FileItemDatabase implements ChangeExecListener {
             }
         }
 
-        con.commit();
-
         try (final ResultSet resultSet = selectStmt.getResultSet()) {
             final ArrayList<FileStoreData> fileStoreDataList = new ArrayList<>();
 
@@ -1103,6 +1120,9 @@ public class FileItemDatabase implements ChangeExecListener {
             return FileItemUtils.listToArray(fileStoreDataList, FileStoreData.class);
         } catch (Exception e) {
             throw new FileItemException(e);
+        } finally {
+            // commit even pure query statements, since they could produce transactions (e.g. for AWS RDB)
+            con.commit();
         }
     }
 
@@ -1111,7 +1131,7 @@ public class FileItemDatabase implements ChangeExecListener {
      * @param selectStmt
      * @return
      */
-    private static FileItem[] implExecuteQuery(@NonNull final String groupId, @NonNull final PreparedStatement queryStmt, Object... returnValues) throws FileItemException {
+    private static FileItem[] implExecuteQuery(@NonNull final Connection con, @NonNull final String groupId, @NonNull final PreparedStatement queryStmt, Object... returnValues) throws Exception {
         try (final ResultSet resultSet = queryStmt.executeQuery()) {
             final ArrayList<FileItem> fileItemList = new ArrayList<>();
 
@@ -1159,6 +1179,9 @@ public class FileItemDatabase implements ChangeExecListener {
             return FileItemUtils.listToArray(fileItemList, FileItem.class);
         } catch (Exception e) {
             throw new FileItemException(e);
+        } finally {
+            // commit even pure query statements, since they could produce transactions (e.g. for AWS RDB)
+            con.commit();
         }
     }
 
@@ -1244,42 +1267,46 @@ public class FileItemDatabase implements ChangeExecListener {
         final String selectSql = STR_BUILDER("SELECT fg.GroupId, fg.PropertyKeys, fg.SubGroupCount FROM ").append(TBL_GROUPADMIN("fg")).toString();
 
         try (final Connection con = getReadConnection();
-             final PreparedStatement stmt = con.prepareStatement(selectSql);
-             final ResultSet resultSet = stmt.executeQuery()) {
+             final PreparedStatement stmt = con.prepareStatement(selectSql)) {
 
-            if (null != resultSet) {
-                while (resultSet.next()) {
-                    final String curGroupId = resultSet.getString(1);
+            try (final ResultSet resultSet = stmt.executeQuery()) {
+                if (null != resultSet) {
+                    while (resultSet.next()) {
+                        final String curGroupId = resultSet.getString(1);
 
-                    if (FileItemUtils.isValid(curGroupId)) {
-                        final Set<String> propertyKeySet = implGetKeySet(curGroupId, false);
-                        final Set<String> customKeySet = implGetKeySet(curGroupId, true);
-                        final String curPropertyKeys = resultSet.getString(2);
-                        final long subGroupCount = resultSet.getLong(3);
+                        if (FileItemUtils.isValid(curGroupId)) {
+                            final Set<String> propertyKeySet = implGetKeySet(curGroupId, false);
+                            final Set<String> customKeySet = implGetKeySet(curGroupId, true);
+                            final String curPropertyKeys = resultSet.getString(2);
+                            final long subGroupCount = resultSet.getLong(3);
 
-                        // add to set for given groupId, if not already present
-                        if (isNotEmpty(curPropertyKeys)) {
-                            final String[] keys  = new String(curPropertyKeys).split(",", 0);
+                            // add to set for given groupId, if not already present
+                            if (isNotEmpty(curPropertyKeys)) {
+                                final String[] keys  = new String(curPropertyKeys).split(",", 0);
 
-                            if (null != keys) {
-                                for (final String curKey : keys) {
-                                    if (isNotBlank(curKey)) {
-                                        final String targetKey = curKey.trim();
+                                if (null != keys) {
+                                    for (final String curKey : keys) {
+                                        if (isNotBlank(curKey)) {
+                                            final String targetKey = curKey.trim();
 
-                                        propertyKeySet.add(targetKey);
+                                            propertyKeySet.add(targetKey);
 
-                                        if (!implIsDefaultKey(curKey)) {
-                                            customKeySet.add(targetKey);
+                                            if (!implIsDefaultKey(curKey)) {
+                                                customKeySet.add(targetKey);
+                                            }
                                         }
                                     }
                                 }
                             }
-                        }
 
-                        // update GroupCount
-                        implSetSubGroupCount(curGroupId, subGroupCount);
+                            // update GroupCount
+                            implSetSubGroupCount(curGroupId, subGroupCount);
+                        }
                     }
                 }
+            } finally {
+                // commit even pure query statements, since they could produce transactions (e.g. for AWS RDB)
+                con.commit();
             }
         } catch (SQLException e) {
             throw new FileItemException(e);
