@@ -133,9 +133,7 @@ public class ImageConverterServerRest extends JAXRSService {
     @Path("/status/")
     @Produces(MediaType.TEXT_HTML)
     public String status(@QueryParam("metrics") @DefaultValue("false") String metrics) {
-        if (LOG.isTraceEnabled()) {
-            LOG.trace("IC WebService received #status request");
-        }
+        LOG.trace("IC WebService received #status request");
 
         return implCreateImageConverterServerHtmlPage(m_terminated.get() ?
             OX_IMAGECONVERTER_SERVER_TERMINATED_RESPONSE_TEXT :
@@ -160,10 +158,7 @@ public class ImageConverterServerRest extends JAXRSService {
         @PathParam("requestFormat") String requestFormat,
         @QueryParam("context") @DefaultValue("") String context) {
 
-        if (LOG.isTraceEnabled()) {
-            LOG.trace(new StringBuilder("IC WebService received #getImage request: ").
-                append(imageKey).append(" / ").append(requestFormat).toString());
-        }
+        LOG.trace("IC WebService received #getImage request: {} / {}", imageKey, requestFormat);
 
         ResponseBuilder responseBuilder = null;
 
@@ -172,7 +167,7 @@ public class ImageConverterServerRest extends JAXRSService {
                 responseBuilder = implCreateFileResponse(inputStm);
             } catch (Exception e) {
                 responseBuilder = implCreateExceptionResponse(e);
-                LOG.trace(Throwables.getRootCause(e).getMessage());
+                LOG.trace("IC WebService error in #getImage", e);
             }
         } else {
             responseBuilder = implCreateImageConverterErrorResponse("ImageConverter server terminated!");
@@ -193,10 +188,7 @@ public class ImageConverterServerRest extends JAXRSService {
     public Response getMetadata(@PathParam("imageKey") String imageKey,
         @QueryParam("context") @DefaultValue("") String context) {
 
-        if (LOG.isTraceEnabled()) {
-            LOG.trace(new StringBuilder("IC WebService received #getMetadata request: ").
-                append(imageKey).toString());
-        }
+    	LOG.trace("IC WebService received #getMetadata request: {}", imageKey);
 
         ResponseBuilder responseBuilder = null;
 
@@ -209,7 +201,7 @@ public class ImageConverterServerRest extends JAXRSService {
                 }
             } catch (Exception e) {
                 responseBuilder = implCreateExceptionResponse(e);
-                LOG.error(Throwables.getRootCause(e).getMessage());
+                LOG.error("IC WebService error in #getMetadata", e);
             }
         } else {
             responseBuilder = implCreateImageConverterErrorResponse("ImageConverter server terminated!");
@@ -231,11 +223,7 @@ public class ImageConverterServerRest extends JAXRSService {
         @PathParam("requestFormat") String requestFormat,
         @QueryParam("context") @DefaultValue("") String context) {
 
-        if (LOG.isTraceEnabled()) {
-            LOG.trace(new StringBuilder("IC WebService received #getImageAndMetadata request: ").
-                append(imageKey).append(" / ").
-                append(requestFormat).toString());
-        }
+    	LOG.trace("IC WebService received #getImageAndMetadata request: {} / {}", imageKey, requestFormat);
 
         ResponseBuilder responseBuilder = null;
 
@@ -244,7 +232,7 @@ public class ImageConverterServerRest extends JAXRSService {
                 responseBuilder = implCreateMetadataImageResponse(metadataImage);
             } catch (Exception e) {
                 responseBuilder = implCreateExceptionResponse(e);
-                LOG.error(Throwables.getRootCause(e).getMessage());
+                LOG.error("IC WebService error in #getImageAndMetadata", e);
             }
         } else {
             responseBuilder = implCreateImageConverterErrorResponse("ImageConverter server terminated!");
@@ -265,10 +253,7 @@ public class ImageConverterServerRest extends JAXRSService {
         @PathParam("imageKey") String imageKey,
         @QueryParam("context") @DefaultValue("") String context) {
 
-        if (LOG.isTraceEnabled()) {
-            LOG.trace(new StringBuilder("IC WebService received #cacheImage request: ").
-                append(imageKey).toString());
-        }
+    	LOG.trace("IC WebService received #cacheImage request: {}", imageKey);
 
         ResponseBuilder responseBuilder = null;
 
@@ -282,7 +267,7 @@ public class ImageConverterServerRest extends JAXRSService {
                 }
             } catch (Exception e) {
                 responseBuilder = implCreateExceptionResponse(e);
-                LOG.error(Throwables.getRootCause(e).getMessage());
+                LOG.error("IC WebService error in #cacheImage", e);
             }
         } else {
             responseBuilder = implCreateImageConverterErrorResponse("ImageConverter server terminated!");
@@ -307,11 +292,7 @@ public class ImageConverterServerRest extends JAXRSService {
         @PathParam("requestFormat") String requestFormat,
         @QueryParam("context") @DefaultValue("") String context) {
 
-        if (LOG.isTraceEnabled()) {
-            LOG.trace(new StringBuilder("IC WebService received #cacheAndGetImage request: ").
-                append(imageKey).append(" / ").
-                append(requestFormat).toString());
-        }
+        LOG.trace("IC WebService received #cacheAndGetImage request: {} / {}", imageKey, requestFormat);
 
         ResponseBuilder responseBuilder = null;
 
@@ -326,7 +307,7 @@ public class ImageConverterServerRest extends JAXRSService {
                 }
             } catch (Exception e) {
                 responseBuilder = implCreateExceptionResponse(e);
-                LOG.error(Throwables.getRootCause(e).getMessage());
+                LOG.error("IC WebService error in #cacheAndGetImage", e);
             }
         } else {
             responseBuilder = implCreateImageConverterErrorResponse("ImageConverter server terminated!");
@@ -351,11 +332,7 @@ public class ImageConverterServerRest extends JAXRSService {
         @PathParam("requestFormat") String requestFormat,
         @QueryParam("context") @DefaultValue("") String context) {
 
-        if (LOG.isTraceEnabled()) {
-            LOG.trace(new StringBuilder("IC WebService received #cacheAndGetImageAndMetadata request: ").
-                append(imageKey).append(" / ").
-                append(requestFormat).toString());
-        }
+        LOG.trace("IC WebService received #cacheAndGetImageAndMetadata request: {} / {}", imageKey, requestFormat);
 
         ResponseBuilder responseBuilder = null;
 
@@ -370,7 +347,7 @@ public class ImageConverterServerRest extends JAXRSService {
                 }
             } catch (Exception e) {
                 responseBuilder = implCreateExceptionResponse(e);
-                LOG.error(Throwables.getRootCause(e).getMessage());
+                LOG.error("IC WebService error in #cacheAndGetImageAndMetadata", e);
             }
         } else {
             responseBuilder = implCreateImageConverterErrorResponse("ImageConverter server terminated!");
@@ -387,9 +364,7 @@ public class ImageConverterServerRest extends JAXRSService {
     public Response clearImages(@QueryParam("context") @DefaultValue("") String context) {
         ResponseBuilder responseBuilder = null;
 
-        if (LOG.isTraceEnabled()) {
-            LOG.trace("IC WebService received #clearImages' request: ");
-        }
+        LOG.trace("IC WebService received #clearImages request");
 
         if (!m_terminated.get()) {
             try {
@@ -402,7 +377,7 @@ public class ImageConverterServerRest extends JAXRSService {
                 responseBuilder = implCreateSuccessResponse();
             } catch (ImageConverterException e) {
                 responseBuilder = implCreateExceptionResponse(e);
-                LOG.error(Throwables.getRootCause(e).getMessage());
+                LOG.error("IC WebService error in #clearImages", e);
             }
         } else {
             responseBuilder = implCreateImageConverterErrorResponse("ImageConverter server terminated!");
@@ -420,10 +395,7 @@ public class ImageConverterServerRest extends JAXRSService {
     public Response clearImagesByKey(@PathParam("imageKey") String imageKey) {
         ResponseBuilder responseBuilder = null;
 
-        if (LOG.isTraceEnabled()) {
-            LOG.trace(new StringBuilder("IC WebService received #clearImagesByKey request: ").
-                append(imageKey).toString());
-        }
+        LOG.trace("IC WebService received #clearImagesByKey request: {}", imageKey);
 
         if (!m_terminated.get()) {
             try {
@@ -431,7 +403,7 @@ public class ImageConverterServerRest extends JAXRSService {
                 responseBuilder = implCreateSuccessResponse();
             } catch (ImageConverterException e) {
                 responseBuilder = implCreateExceptionResponse(e);
-                LOG.error(Throwables.getRootCause(e).getMessage());
+                LOG.error("IC WebService error in #clearImagesByKey", e);
             }
         } else {
             responseBuilder = implCreateImageConverterErrorResponse("ImageConverter server terminated!");
@@ -450,21 +422,19 @@ public class ImageConverterServerRest extends JAXRSService {
     public JSONObject getKeyCount(@QueryParam("context") @DefaultValue("") String context) {
         JSONObject ret = new JSONObject();
 
-        if (LOG.isTraceEnabled()) {
-            LOG.trace("IC WebService received #getKeyCount request");
-        }
+        LOG.trace("IC WebService received #getKeyCount request");
 
         if (!m_terminated.get()) {
             try {
                 ret.put("count", m_imageConverter.getKeyCount(context));
             } catch (Exception e) {
-                LOG.error(Throwables.getRootCause(e).getMessage());
+            	LOG.error("IC WebService error in #getKeyCount", e);
             }
         } else {
             try {
                 ret = new JSONObject(implCreateJSONResponse(CODE_ERROR_TERMINATED, MESSAGE_ERROR_TERMINATED));
             } catch (Exception e) {
-                LOG.error(Throwables.getRootCause(e).getMessage());
+                LOG.error("IC WebService error in #getKeyCount", e);
             }
         }
 
@@ -483,20 +453,18 @@ public class ImageConverterServerRest extends JAXRSService {
         JSONObject ret = new JSONObject();
 
         if (!m_terminated.get()) {
-            if (LOG.isTraceEnabled()) {
-                LOG.trace("IC WebService received #getKey request");
-            }
+            LOG.trace("IC WebService received #getKey request");
 
             try {
                 ret.put("keys", Arrays.asList(m_imageConverter.getKeys(context)));
             } catch (Exception e) {
-                LOG.error(Throwables.getRootCause(e).getMessage());
+            	LOG.error("IC WebService error in #getKeys", e);
             }
         } else {
             try {
                 ret = new JSONObject(implCreateJSONResponse(CODE_ERROR_TERMINATED, MESSAGE_ERROR_TERMINATED));
             } catch (Exception e) {
-                LOG.error(Throwables.getRootCause(e).getMessage());
+            	LOG.error("IC WebService error in #getKeys", e);
             }
         }
 
@@ -508,9 +476,7 @@ public class ImageConverterServerRest extends JAXRSService {
      */
     public void shutdown() {
         if (m_terminated.compareAndSet(false, true)) {
-            if (LOG.isTraceEnabled()) {
-                LOG.trace("ImageConverter server shutdown finished");
-            }
+            LOG.trace("ImageConverter server shutdown finished");
         }
     }
 
@@ -540,7 +506,7 @@ public class ImageConverterServerRest extends JAXRSService {
         }
 
         if (null != monitoring) {
-            htmlBuilder.append("</br>").append("<p><u>Metrics</u></p>");
+            htmlBuilder.append("<br />").append("<p><u>Metrics</u></p>");
 
             for (Method method : monitoring.getClass().getMethods())
                 if (null != method) {
@@ -677,7 +643,7 @@ public class ImageConverterServerRest extends JAXRSService {
             responseObject.put("code", code);
             responseObject.put("message", isNotEmpty(message) ? message : MESSAGE_SUCCESS);
         } catch (JSONException e) {
-            LOG.error(Throwables.getRootCause(e).getMessage());
+        	LOG.error(e.getMessage(), e);
         }
 
         return responseObject.toString();
@@ -705,7 +671,7 @@ public class ImageConverterServerRest extends JAXRSService {
                 }
             }
         } catch (IOException e) {
-            LOG.error(Throwables.getRootCause(e).getMessage());
+            LOG.error(e.getMessage(), e);
         }
 
         return ret;
