@@ -62,7 +62,6 @@ import java.util.Properties;
 import java.util.Set;
 import java.util.concurrent.atomic.AtomicBoolean;
 import org.apache.commons.lang.ArrayUtils;
-import com.google.common.base.Throwables;
 import com.openexchange.annotation.NonNull;
 import com.openexchange.annotation.Nullable;
 import com.openexchange.imageconverter.api.ElementLock;
@@ -151,17 +150,12 @@ public final class ImageConverter implements IImageConverter {
         if (m_terminated.compareAndSet(false, true)) {
             final long shutdownStartTimeMillis = System.currentTimeMillis();
 
-            if (LOG.isInfoEnabled()) {
-                LOG.info("IC starting shutdown");
-            }
+            LOG.info("IC starting shutdown");
 
             m_keyManager.shutdown();
             m_imageConversionQueue.shutdown();
 
-            if (LOG.isInfoEnabled()) {
-                LOG.info(new StringBuilder("IC shutdown finished in ").
-                    append(System.currentTimeMillis() - shutdownStartTimeMillis).append("ms").toString());
-            }
+            LOG.info("IC shutdown finished in {}ms", (System.currentTimeMillis() - shutdownStartTimeMillis));
         }
     }
 
@@ -203,9 +197,7 @@ public final class ImageConverter implements IImageConverter {
 
             return ret;
         } catch (IOException | ImageConverterException e) {
-            if (LOG.isTraceEnabled()) {
-                LOG.trace("IC exception while getting MetadataImage: " + Throwables.getRootCause(e));
-            }
+            LOG.trace("IC exception while getting MetadataImage", e);
 
             status = ImageConverterStatus.GENERAL_ERROR;
             throw new ImageConverterException("IC error while getting MetadataImage: " + imageKey, e);
@@ -240,9 +232,7 @@ public final class ImageConverter implements IImageConverter {
 
             return ret;
         } catch (ImageConverterException e) {
-            if (LOG.isTraceEnabled()) {
-                LOG.trace("IC exception while getting Metadata: " + Throwables.getRootCause(e));
-            }
+            LOG.trace("IC exception while getting Metadata", e);
 
             status = ImageConverterStatus.GENERAL_ERROR;
             throw e;
@@ -277,9 +267,7 @@ public final class ImageConverter implements IImageConverter {
 
             return ret;
         } catch (ImageConverterException e) {
-            if (LOG.isTraceEnabled()) {
-                LOG.trace("IC exception while getting ImageAndMetadata: " + Throwables.getRootCause(e));
-            }
+            LOG.trace("IC exception while getting ImageAndMetadata", e);
 
             status = ImageConverterStatus.GENERAL_ERROR;
             throw e;
@@ -308,9 +296,7 @@ public final class ImageConverter implements IImageConverter {
                 m_imageConversionQueue.cache(imageKey, srcImageStm, implGetContext(context), null);
             }
         } catch (ImageConverterException e) {
-            if (LOG.isTraceEnabled()) {
-                LOG.trace("IC exception while caching Image: " + Throwables.getRootCause(e));
-            }
+            LOG.trace("IC exception while caching Image", e);
 
             status = ImageConverterStatus.GENERAL_ERROR;
             throw e;
@@ -358,9 +344,7 @@ public final class ImageConverter implements IImageConverter {
                 }
             }
         } catch (IOException | ImageConverterException e) {
-            if (LOG.isTraceEnabled()) {
-                LOG.trace("IC exception while caching and getting Image: " + Throwables.getRootCause(e));
-            }
+            LOG.trace("IC exception while caching and getting Image" ,e);
 
             status = ImageConverterStatus.GENERAL_ERROR;
             throw new ImageConverterException("IC error while caching and getting image: " + imageKey, e);
@@ -395,9 +379,7 @@ public final class ImageConverter implements IImageConverter {
                         m_imageConversionQueue.getMetadataImage(imageKey, requestFormat, usedContext);
             }
         } catch (ImageConverterException e) {
-            if (LOG.isTraceEnabled()) {
-                LOG.trace("IC exception while caching and getting ImageAndMetadata: " + Throwables.getRootCause(e));
-            }
+            LOG.trace("IC exception while caching and getting ImageAndMetadata", e);
 
             status = ImageConverterStatus.GENERAL_ERROR;
             throw e;
@@ -424,9 +406,7 @@ public final class ImageConverter implements IImageConverter {
         try {
             remove(getAvailable(implCreateContextProperties(context)));
         } catch (ImageConverterException e) {
-            if (LOG.isTraceEnabled()) {
-                LOG.trace("IC exception while clearing Images: " + Throwables.getRootCause(e));
-            }
+            LOG.trace("IC exception while clearing Images", e);
 
             status = ImageConverterStatus.GENERAL_ERROR;
             throw e;
@@ -455,9 +435,7 @@ public final class ImageConverter implements IImageConverter {
                 remove(imageKey);
             }
         } catch (ImageConverterException e) {
-            if (LOG.isTraceEnabled()) {
-                LOG.trace("IC exception while clearing Images by key: " + Throwables.getRootCause(e));
-            }
+            LOG.trace("IC exception while clearing Images by key", e);
 
             status = ImageConverterStatus.GENERAL_ERROR;
             throw e;
@@ -484,9 +462,7 @@ public final class ImageConverter implements IImageConverter {
                 getKeyCount() :
                     getAvailable(implCreateContextProperties(context)).length;
         } catch (ImageConverterException e) {
-            if (LOG.isTraceEnabled()) {
-                LOG.trace("IC exception while getting KeyCount: " + Throwables.getRootCause(e));
-            }
+            LOG.trace("IC exception while getting KeyCount", e);
 
             status = ImageConverterStatus.GENERAL_ERROR;
             throw e;
@@ -511,9 +487,7 @@ public final class ImageConverter implements IImageConverter {
         try {
             return getAvailable(implCreateContextProperties(context));
         } catch (ImageConverterException e) {
-            if (LOG.isTraceEnabled()) {
-                LOG.trace("IC exception while getting Keys: " + Throwables.getRootCause(e));
-            }
+            LOG.trace("IC exception while getting Keys", e);
 
             status = ImageConverterStatus.GENERAL_ERROR;
             throw e;
@@ -540,9 +514,7 @@ public final class ImageConverter implements IImageConverter {
                 getTotalImagesSize() :
                     getAvailableImagesSize(implCreateContextProperties(context));
         } catch (ImageConverterException e) {
-            if (LOG.isTraceEnabled()) {
-                LOG.trace("IC exception while getting TotalImagesSize: " + Throwables.getRootCause(e));
-            }
+            LOG.trace("IC exception while getting TotalImagesSize", e);
 
             status = ImageConverterStatus.GENERAL_ERROR;
             throw e;
@@ -763,6 +735,7 @@ public final class ImageConverter implements IImageConverter {
      * @param context
      */
     private static void implTrace(final String traceMsg, final String... context) {
+    	// TODO
         if (LOG.isTraceEnabled() && (null != traceMsg)) {
             LOG.trace(isNotEmpty(context) ?
                 new StringBuilder(traceMsg).append( "(Context: ").append(context[0]).append(")").toString() :
