@@ -252,9 +252,7 @@ class ImageConverterQueue extends Thread {
         try {
             ret = getMetadataImage(imageKey, requestFormat, context);
         } catch (ImageConverterException e) {
-            if (LOG.isTraceEnabled()) {
-                LOG.trace("IC not able to read MetadataImage: " + Throwables.getRootCause(e));
-            }
+            LOG.trace("IC not able to read MetadataImage", e);
         }
 
         if (null == ret) {
@@ -296,8 +294,6 @@ class ImageConverterQueue extends Thread {
                 imageMetadata,
                 ImageFormat.parseImageFormat(requestFormat));
 
-            long n = 0;
-
             if (null == requestTargetFormat) {
                 throw new ImageConverterException(new StringBuilder("IC error while parsing requested image format for ").
                     append(imageKey).append(": ").
@@ -394,18 +390,13 @@ class ImageConverterQueue extends Thread {
                 m_imageProcessor.shutdown();
                 m_executorThreads.awaitTermination(ImageConverterUtils.AWAIT_TERMINATION_TIMEOUT_MILLIS, TimeUnit.MILLISECONDS);
             } catch (@SuppressWarnings("unused") InterruptedException e) {
-                if (trace) {
-                    LOG.trace("IC queue received interrupt while awaiting termination");
-                }
+                LOG.trace("IC queue received interrupt while awaiting termination");
 
                 Thread.currentThread().interrupt();
             }
 
-            if (trace) {
-                LOG.trace("IC queue shutdown open Runnable count after shutdown: " + m_processingMap.size());
-                LOG.trace(new StringBuilder("IC queue shutdown finished in ").
-                    append(System.currentTimeMillis() - shutdownStartTimeMillis).append("ms").toString());
-            }
+            LOG.trace("IC queue shutdown open Runnable count after shutdown: {}" + m_processingMap.size());
+            LOG.trace("IC queue shutdown finished in {}ms", (System.currentTimeMillis() - shutdownStartTimeMillis));
         }
     }
 
@@ -434,10 +425,8 @@ class ImageConverterQueue extends Thread {
         @Nullable final String context,
         @NonNull final ImageConverterPriority imageConverterPriority) throws ImageConverterException {
 
-        final boolean trace = LOG.isTraceEnabled();
-
-        if (trace && m_processingMap.containsKey(imageKey)) {
-            LOG.trace("IC queue processing map already contains imageKey while start queueing: " + imageKey);
+        if (m_processingMap.containsKey(imageKey)) {
+            LOG.trace("IC queue processing map already contains imageKey while start queueing: {}", imageKey);
         }
 
         ImageConverterRunnable imageConverterRunnable = null;
@@ -548,25 +537,19 @@ class ImageConverterQueue extends Thread {
      * @throws ImageConverterException
      */
     void closeRunnable(@NonNull String imageKey, @Nullable final ImageConverterRunnable imageConverterRunnableImpl, final boolean remove) {
-        final boolean trace = LOG.isTraceEnabled();
-
         try {
             if (remove) {
                 m_fileItemService.removeSubGroup(ImageConverterUtils.IMAGECONVERTER_GROUPID, imageKey);
             }
         } catch (FileItemException e) {
-            if (trace) {
-                LOG.trace("IC error while removing imageKey when closing Runnable: " + imageKey, Throwables.getRootCause(e));
-            }
+            LOG.trace("IC error while removing imageKey when closing Runnable: {}", imageKey, e);
         } finally {
             if (null != imageConverterRunnableImpl) {
                 imageConverterRunnableImpl.close();
             }
         }
 
-        if (trace) {
-            LOG.trace("IC queue ended Runnable: " + imageKey);
-        }
+        LOG.trace("IC queue ended Runnable: {}", imageKey);
     }
 
     /**
