@@ -144,7 +144,7 @@ class ImageConverterRunnable implements Runnable, Closeable {
         FileUtils.deleteQuietly(m_inputFile);
         m_inputFile = null;
 
-        m_processFormatMap.clear();
+        m_formatsToProcess.clear();
     }
 
     /*
@@ -162,7 +162,7 @@ class ImageConverterRunnable implements Runnable, Closeable {
         m_queue.startProcessing(m_imageKey, this);
 
         try {
-            for (final Iterator<ImageFormat> iter = m_processFormatMap.keySet().iterator(); iter.hasNext() && !finished;) {
+            for (final Iterator<ImageFormat> iter = m_formatsToProcess.keySet().iterator(); iter.hasNext() && !finished;) {
                 curTargetFormat = iter.next();
 
                 if (LOG.isTraceEnabled()) {
@@ -217,14 +217,14 @@ class ImageConverterRunnable implements Runnable, Closeable {
      * @throws ImageConverterException
      */
     protected void processMapKey(@NonNull final ImageFormat targetFormat, final boolean isAsync) throws ImageConverterException {
-        ImageFormat processingFormat = m_processFormatMap.get(targetFormat);
+        ImageFormat processingFormat = m_formatsToProcess.get(targetFormat);
         final long subProcessingStartTimeMillis = System.currentTimeMillis();
 
         if (null == processingFormat) {
             // check first, if we need to create the reference format entry
-            if ((null != m_referenceFormat) && (null != (processingFormat = m_processFormatMap.get(m_referenceFormat)))) {
+            if ((null != m_referenceFormat) && (null != (processingFormat = m_formatsToProcess.get(m_referenceFormat)))) {
                 implCreateThumbnail(m_imageKey, m_inputFile, m_imageMetadata, m_referenceFormat, processingFormat, m_context, isAsync);
-                m_processFormatMap.remove(m_referenceFormat);
+                m_formatsToProcess.remove(m_referenceFormat);
             }
 
             implCreatReferenceThumbnail(m_imageKey, m_imageMetadata, targetFormat, m_referenceFormat, m_context, isAsync);
@@ -255,7 +255,7 @@ class ImageConverterRunnable implements Runnable, Closeable {
             }
 
             processMapKey(requestTargetFormat, false);
-            m_processFormatMap.remove(requestTargetFormat);
+            m_formatsToProcess.remove(requestTargetFormat);
 
             ret = new MetadataImage(ImageConverterUtils.readImageByTargetFormat(m_fileItemService, m_imageKey, requestTargetFormat), m_imageMetadata);
         } catch (Exception e) {
@@ -311,9 +311,9 @@ class ImageConverterRunnable implements Runnable, Closeable {
                 // reference format result, in order to properly
                 // use the reference format
                 if (ImageConverterUtils.shouldUseReferenceFormat(imageDimension, curImageFormat)) {
-                    m_processFormatMap.put(curImageFormat, null);
+                    m_formatsToProcess.put(curImageFormat, null);
                 } else {
-                    m_processFormatMap.put(curImageFormat, curImageFormat);
+                    m_formatsToProcess.put(curImageFormat, curImageFormat);
                 }
 
             } else if (ImageConverterUtils.shouldUseReferenceFormat(imageDimension, curImageFormat)) {
@@ -325,9 +325,9 @@ class ImageConverterRunnable implements Runnable, Closeable {
                     false,
                     curImageFormat.getQuality());
 
-                m_processFormatMap.put(m_referenceFormat = curImageFormat, originalFormat);
+                m_formatsToProcess.put(m_referenceFormat = curImageFormat, originalFormat);
             } else {
-                m_processFormatMap.put(curImageFormat, curImageFormat);
+                m_formatsToProcess.put(curImageFormat, curImageFormat);
             }
         }
     }
@@ -363,7 +363,7 @@ class ImageConverterRunnable implements Runnable, Closeable {
                     }
                 }
             } catch (Exception e) {
-                LOG.error("IC error while creating metadata entry: " + imageKey, e);
+                LOG.error("IC error while creating metadata entry: {}", imageKey, e);
 
                 implRemoveFile(imageKey, ImageConverterUtils.IMAGECONVERTER_METADATA_FILEID);
                 ret = null;
@@ -495,7 +495,7 @@ class ImageConverterRunnable implements Runnable, Closeable {
             if (LOG.isTraceEnabled()) {
                 LOG.trace(new StringBuilder("IC error while removing file for ").
                     append(imageKey).append(": ").
-                    append(fileName).toString(), Throwables.getRootCause(e));
+                    append(fileName).toString(), e);
             }
         }
     }
@@ -563,7 +563,7 @@ class ImageConverterRunnable implements Runnable, Closeable {
 
     final private List<ImageFormat> m_imageFormats;
 
-    final private Map<ImageFormat, ImageFormat> m_processFormatMap = new LinkedHashMap<>();
+    final private Map<ImageFormat, ImageFormat> m_formatsToProcess = new LinkedHashMap<>();
 
     final private String m_imageKey;
 
